@@ -386,12 +386,16 @@ def ask_for_port(type):
             ports = [port.device for port in portslist if port.device == '/dev/cu.usbserial-MX0101']
         elif type == 'proxy':
             ports = [port.device for port in portslist if port.device == '/dev/cu.usbserial-MX0201']
+        elif type == 'cli':
+            ports = [port.device for port in portslist if port.device == '/dev/cu.usbserial-MX0301']
     else:
         if type == 'sniffer':
             ports = [port.device for port in portslist if port.serial_number == 'MX0101']
         elif type == 'proxy':
             ports = [port.device for port in portslist if port.serial_number == 'MX0201']
-    
+        elif type == 'cli':
+            ports = [port.device for port in portslist if port.serial_number == 'MX0301']
+
     if len(ports) == 0:
       sys.stderr.write('ERROR: Dongle was not found!\n')
       sys.exit(1)
@@ -556,9 +560,15 @@ class Miniterm(object):
                     self.stop()             # exit app
                     break
                 elif c == self.reboot_character:
-                    self.serial.write(self.tx_encoder.encode('kernel reboot cold\r\n\r\n'))
+                    if self.type == 'cli':
+                        self.serial.write(self.tx_encoder.encode(c))
+                    else:
+                        self.serial.write(self.tx_encoder.encode('kernel reboot cold\r\n\r\n'))
                 elif c == self.start_character:
-                    self.serial.write(self.tx_encoder.encode('sniffer start\r\n'))
+                    if self.type == 'cli':
+                        self.serial.write(self.tx_encoder.encode(c))
+                    else:
+                        self.serial.write(self.tx_encoder.encode('sniffer start\r\n'))
                 else:
                     #~ if self.raw:
                     text = c
@@ -1049,6 +1059,7 @@ def main(default_type='sniffer', default_port=None, default_baudrate=921600, def
     miniterm.raw = args.raw
     miniterm.set_rx_encoding(args.serial_port_encoding)
     miniterm.set_tx_encoding(args.serial_port_encoding)
+    miniterm.type = args.type
 
     if not args.quiet:
         sys.stderr.write('--- xMesh Assistant on {p.name}  {p.baudrate},{p.bytesize},{p.parity},{p.stopbits} ---\n'.format(
